@@ -159,6 +159,11 @@ class BaseQueryCompiler(abc.ABC):
         # TODO create a way to clean up this object.
         pass
 
+    @abc.abstractmethod
+    def finalize(self):
+        """Finalize constructing the dataframe calling all deferred functions which were used to build it."""
+        pass
+
     # END Data Management Methods
 
     # To/From Pandas
@@ -568,21 +573,59 @@ class BaseQueryCompiler(abc.ABC):
         """
         return DataFrameDefault.register(pandas.DataFrame.min)(self, **kwargs)
 
-    def prod(self, **kwargs):
+    def prod(self, squeeze_self, axis, **kwargs):
         """Returns the product of each numerical column or row.
 
         Return:
             Pandas series with the product of each numerical column or row.
         """
-        return DataFrameDefault.register(pandas.DataFrame.prod)(self, **kwargs)
+        # TODO: rework to original implementation after pandas issue #41074 resolves if possible.
+        def map_func(df, **kwargs):
+            """Apply .prod to DataFrame or Series in depend on `squeeze_self.`"""
+            if squeeze_self:
+                result = df.squeeze(axis=1).prod(**kwargs)
+                if is_scalar(result):
+                    if axis:
+                        return pandas.DataFrame(
+                            [result], index=["__reduced__"], columns=["__reduced__"]
+                        )
+                    else:
+                        return pandas.Series([result], index=[df.columns[0]])
+                else:
+                    return result
+            else:
+                return df.prod(**kwargs)
 
-    def sum(self, **kwargs):
+        return DataFrameDefault.register(
+            map_func,
+        )(self, axis=axis, **kwargs)
+
+    def sum(self, squeeze_self, axis, **kwargs):
         """Returns the sum of each numerical column or row.
 
         Return:
             Pandas series with the sum of each numerical column or row.
         """
-        return DataFrameDefault.register(pandas.DataFrame.sum)(self, **kwargs)
+        # TODO: rework to original implementation after pandas issue #41074 resolves if possible.
+        def map_func(df, **kwargs):
+            """Apply .sum to DataFrame or Series in depend on `squeeze_self.`"""
+            if squeeze_self:
+                result = df.squeeze(axis=1).sum(**kwargs)
+                if is_scalar(result):
+                    if axis:
+                        return pandas.DataFrame(
+                            [result], index=["__reduced__"], columns=["__reduced__"]
+                        )
+                    else:
+                        return pandas.Series([result], index=[df.columns[0]])
+                else:
+                    return result
+            else:
+                return df.sum(**kwargs)
+
+        return DataFrameDefault.register(
+            map_func,
+        )(self, axis=axis, **kwargs)
 
     def to_datetime(self, *args, **kwargs):
         return SeriesDefault.register(pandas.to_datetime)(self, *args, **kwargs)
@@ -1907,8 +1950,8 @@ class BaseQueryCompiler(abc.ABC):
     invert = DataFrameDefault.register(pandas.DataFrame.__invert__)
     mad = DataFrameDefault.register(pandas.DataFrame.mad)
     kurt = DataFrameDefault.register(pandas.DataFrame.kurt)
-    sum_min_count = DataFrameDefault.register(pandas.DataFrame.sum)
-    prod_min_count = DataFrameDefault.register(pandas.DataFrame.prod)
+    sum_min_count = sum
+    prod_min_count = prod
     compare = DataFrameDefault.register(pandas.DataFrame.compare)
 
     # End of DataFrame methods
