@@ -16,8 +16,9 @@ import sys
 from textwrap import dedent
 import warnings
 from packaging import version
+import secrets
 
-from .pubsub import Parameter, _TYPE_PARAMS, ExactStr
+from .pubsub import Parameter, _TYPE_PARAMS, ExactStr, ValueSource
 
 
 class EnvironmentVariable(Parameter, type=str, abstract=True):
@@ -65,7 +66,7 @@ class Engine(EnvironmentVariable, type=str):
         except ImportError:
             pass
         else:
-            if version.parse(ray.__version__) < version.parse("1.0.0"):
+            if version.parse(ray.__version__) < version.parse("1.4.0"):
                 raise ImportError(
                     "Please `pip install modin[ray]` to install compatible Ray version."
                 )
@@ -94,7 +95,7 @@ class Backend(EnvironmentVariable, type=str):
 
     varname = "MODIN_BACKEND"
     default = "Pandas"
-    choices = ("Pandas", "OmniSci", "Pyarrow")
+    choices = ("Pandas", "OmniSci", "Pyarrow", "Cudf")
 
 
 class IsExperimental(EnvironmentVariable, type=bool):
@@ -121,6 +122,15 @@ class RayRedisAddress(EnvironmentVariable, type=ExactStr):
     varname = "MODIN_REDIS_ADDRESS"
 
 
+class RayRedisPassword(EnvironmentVariable, type=ExactStr):
+    """
+    What password to use for connecting to Redis
+    """
+
+    varname = "MODIN_REDIS_PASSWORD"
+    default = secrets.token_hex(32)
+
+
 class CpuCount(EnvironmentVariable, type=int):
     """
     How many CPU cores to use when initialization of the Modin engine.
@@ -135,6 +145,14 @@ class CpuCount(EnvironmentVariable, type=int):
         return multiprocessing.cpu_count()
 
 
+class GpuCount(EnvironmentVariable, type=int):
+    """
+    How may GPU devices to utilize across the whole distribution
+    """
+
+    varname = "MODIN_GPUS"
+
+
 class Memory(EnvironmentVariable, type=int):
     """
     How much memory give to each Ray worker (in bytes)
@@ -149,16 +167,9 @@ class NPartitions(EnvironmentVariable, type=int):
     """
 
     varname = "MODIN_NPARTITIONS"
-    # This flag is used to detect whether NPartitions is default value or not
-    _is_default = False
 
     @classmethod
-    def put(cls, value):
-        super().put(value)
-        cls._is_default = False
-
-    @classmethod
-    def put_if_default(cls, value):
+    def _put(cls, value):
         """
         Put specific value if NPartitions wasn't set by a user yet
 
@@ -167,29 +178,15 @@ class NPartitions(EnvironmentVariable, type=int):
         This method is used to set NPartitions from cluster resources internally
         and should not be called by a user.
         """
-        if cls._is_default:
+        if cls.get_value_source() == ValueSource.DEFAULT:
             cls.put(value)
 
     @classmethod
     def _get_default(cls):
-        cls._is_default = True
-        return CpuCount.get()
-
-
-class RayPlasmaDir(EnvironmentVariable, type=ExactStr):
-    """
-    Path to Plasma storage for Ray
-    """
-
-    varname = "MODIN_ON_RAY_PLASMA_DIR"
-
-
-class IsOutOfCore(EnvironmentVariable, type=bool):
-    """
-    Changes primary location of the DataFrame to disk, allowing one to exceed total system memory
-    """
-
-    varname = "MODIN_OUT_OF_CORE"
+        if Backend.get() == "Cudf":
+            return GpuCount.get()
+        else:
+            return CpuCount.get()
 
 
 class SocksProxy(EnvironmentVariable, type=ExactStr):
