@@ -391,7 +391,7 @@ class DFAlgQueryCompiler(BaseQueryCompiler):
         ignore_index = kwargs.get("ignore_index", False)
         other_modin_frames = [o._modin_frame for o in other]
 
-        new_modin_frame = self._modin_frame._concat(
+        new_modin_frame = self._modin_frame.concat(
             axis, other_modin_frames, join=join, sort=sort, ignore_index=ignore_index
         )
         return self.__constructor__(new_modin_frame)
@@ -413,6 +413,22 @@ class DFAlgQueryCompiler(BaseQueryCompiler):
             )
         )
 
+    def dropna(self, axis=0, how="any", thresh=None, subset=None):
+        """Returns a new QueryCompiler with null values dropped along given axis.
+
+        Return:
+            a new QueryCompiler
+        """
+        if thresh is not None or axis != 0:
+            return super().dropna(axis=axis, how=how, thresh=thresh, subset=subset)
+
+        if subset is None:
+            subset = self.columns
+        return self.__constructor__(
+            self._modin_frame.dropna(subset=subset, how=how),
+            shape_hint=self._shape_hint,
+        )
+
     def dt_year(self):
         """Extract year from Datetime info
 
