@@ -44,7 +44,7 @@ from .df_algebra import (
 )
 
 from collections import abc
-from pandas.core.dtypes.common import _get_dtype
+from pandas.core.dtypes.common import get_dtype
 
 
 class CalciteBuilder:
@@ -94,7 +94,7 @@ class CalciteBuilder:
 
         def gen_reduce_expr(self):
             count_expr = self._builder._ref(self._arg.modin_frame, self._count_name)
-            count_expr._dtype = _get_dtype(int)
+            count_expr._dtype = get_dtype(int)
             sum_expr = self._builder._ref(self._arg.modin_frame, self._sum_name)
             sum_expr._dtype = self._sum_dtype
             qsum_expr = self._builder._ref(self._arg.modin_frame, self._quad_sum_name)
@@ -161,7 +161,7 @@ class CalciteBuilder:
 
         def gen_reduce_expr(self):
             count_expr = self._builder._ref(self._arg.modin_frame, self._count_name)
-            count_expr._dtype = _get_dtype(int)
+            count_expr._dtype = get_dtype(int)
             sum_expr = self._builder._ref(self._arg.modin_frame, self._sum_name)
             sum_expr._dtype = self._sum_dtype
             qsum_expr = self._builder._ref(self._arg.modin_frame, self._quad_sum_name)
@@ -312,6 +312,17 @@ class CalciteBuilder:
         self._to_calcite(op)
         return self.res
 
+    def _add_projection(self, frame):
+        """
+        Applies projection of the frame columns for table scan and discards
+        virtual "rowid" column.
+        """
+        proj = CalciteProjectionNode(
+            frame._table_cols, [self._ref(frame, col) for col in frame._table_cols]
+        )
+        self._push(proj)
+        return proj
+
     def _input_ctx(self):
         return self._input_ctx_stack[-1]
 
@@ -392,9 +403,7 @@ class CalciteBuilder:
 
         # mask is currently always applied over scan, it means
         # we need additional projection to remove rowid column
-        fields = frame._table_cols
-        exprs = [self._ref(frame, col) for col in frame._table_cols]
-        self._push(CalciteProjectionNode(fields, exprs))
+        self._add_projection(frame)
 
     def _process_groupby(self, op):
         frame = op.input[0]
@@ -473,7 +482,7 @@ class CalciteBuilder:
         """ Join, only equal-join supported """
         cmps = [self._ref(left, c).eq(self._ref(right, c)) for c in op.on]
         if len(cmps) > 1:
-            condition = OpExpr("AND", cmps, _get_dtype(bool))
+            condition = OpExpr("AND", cmps, get_dtype(bool))
         else:
             condition = cmps[0]
         node = CalciteJoinNode(
@@ -521,13 +530,8 @@ class CalciteBuilder:
 
     def _process_sort(self, op):
         frame = op.input[0]
-
-        # Sort should be applied to projections.
         if not isinstance(self._input_node(0), CalciteProjectionNode):
-            proj = CalciteProjectionNode(
-                frame._table_cols, [self._ref(frame, col) for col in frame._table_cols]
-            )
-            self._push(proj)
+            proj = self._add_projection(frame)
             self._input_ctx().replace_input_node(frame, proj, frame._table_cols)
 
         nulls = op.na_position.upper()
@@ -542,3 +546,8 @@ class CalciteBuilder:
     def _process_filter(self, op):
         condition = self._translate(op.condition)
         self._push(CalciteFilterNode(condition))
+
+        if isinstance(self._input_node(0), CalciteScanNode):
+            # if filter was applied over scan, then we need additional
+            # projection to remove rowid column
+            self._add_projection(op.input[0])
