@@ -35,6 +35,10 @@ from modin.pandas.test.utils import (
     eval_io,
 )
 
+from modin.experimental.engines.omnisci_on_ray.frame.partition_manager import (
+    OmnisciOnRayFramePartitionManager,
+)
+
 
 def set_execution_mode(frame, mode, recursive=False):
     if isinstance(frame, (pd.Series, pd.DataFrame)):
@@ -157,7 +161,7 @@ class TestCSV:
     }
 
     def test_usecols_csv(self):
-        """ check with the following arguments: names, dtype, skiprows, delimiter """
+        """check with the following arguments: names, dtype, skiprows, delimiter"""
         csv_file = os.path.join(self.root, "modin/pandas/test/data", "test_usecols.csv")
 
         for kwargs in (
@@ -1663,5 +1667,72 @@ class TestBadData:
         )
 
 
+class TestDropna:
+    data = {
+        "col1": [1, 2, None, 2, 1],
+        "col2": [None, 3, None, 2, 1],
+        "col3": [2, 3, 4, None, 5],
+        "col4": [1, 2, 3, 4, 5],
+    }
+
+    @pytest.mark.parametrize("subset", [None, ["col1", "col2"]])
+    @pytest.mark.parametrize("how", ["all", "any"])
+    def test_dropna(self, subset, how):
+        def applier(df, *args, **kwargs):
+            return df.dropna(subset=subset, how=how)
+
+        run_and_compare(applier, data=self.data)
+
+    def test_dropna_multiindex(self):
+        index = generate_multiindex(len(self.data["col1"]))
+
+        md_df = pd.DataFrame(self.data, index=index)
+        pd_df = pandas.DataFrame(self.data, index=index)
+
+        md_res = md_df.dropna()._to_pandas()
+        pd_res = pd_df.dropna()
+
+        # HACK: all strings in OmniSci considered to be categories, that breaks
+        # checks for equality with pandas, this line discards category dtype
+        md_res.index = pandas.MultiIndex.from_tuples(
+            md_res.index.values, names=md_res.index.names
+        )
+
+        df_equals(md_res, pd_res)
+
+    @pytest.mark.skip("Dropna logic for GroupBy is disabled for now")
+    @pytest.mark.parametrize("by", ["col1", ["col1", "col2"], ["col1", "col4"]])
+    @pytest.mark.parametrize("dropna", [True, False])
+    def test_dropna_groupby(self, by, dropna):
+        def applier(df, *args, **kwargs):
+            # OmniSci backend preserves NaNs at the result of groupby,
+            # so replacing NaNs with '0' to match with Pandas.
+            # https://github.com/modin-project/modin/issues/2878
+            return df.groupby(by=by, dropna=dropna).sum().fillna(0)
+
+        run_and_compare(applier, data=self.data)
+
+
+class TestUnsupportedColumns:
+    @pytest.mark.parametrize(
+        "data,is_good",
+        [
+            [["1", "2", None, "2", "1"], True],
+            [[None, "3", None, "2", "1"], True],
+            [[1, "2", None, "2", "1"], False],
+            [[None, 3, None, "2", "1"], False],
+        ],
+    )
+    def test_unsupported_columns(self, data, is_good):
+        pandas_df = pandas.DataFrame({"col": data})
+        obj, bad_cols = OmnisciOnRayFramePartitionManager._get_unsupported_cols(
+            pandas_df
+        )
+        if is_good:
+            assert obj and not bad_cols
+        else:
+            assert not obj and bad_cols == ["col"]
+
+
 if __name__ == "__main__":
     pytest.main(["-v", __file__])
