@@ -15,10 +15,7 @@
 Implement DataFrame public API as Pandas does.
 
 Almost all docstrings for public and magic methods should be inherited from Pandas
-for better maintability. So some codes are ignored in pydocstyle check:
-    - D101: missing docstring in class
-    - D102: missing docstring in public method
-    - D105: missing docstring in magic method
+for better maintability.
 Manually add documentation for methods which are not presented in pandas.
 """
 
@@ -44,7 +41,7 @@ import warnings
 
 from modin.error_message import ErrorMessage
 from modin.utils import _inherit_docstrings, to_pandas, hashable
-from modin.config import Engine, IsExperimental
+from modin.config import Engine, IsExperimental, PersistentPickle
 from .utils import (
     from_pandas,
     from_non_pandas,
@@ -57,8 +54,10 @@ from .groupby import DataFrameGroupBy
 from .accessor import CachedAccessor, SparseFrameAccessor
 
 
-@_inherit_docstrings(pandas.DataFrame, excluded=[pandas.DataFrame.__init__])
+@_inherit_docstrings(pandas.DataFrame, apilink="pandas.DataFrame")
 class DataFrame(BasePandasDataset):
+    _pandas_class = pandas.DataFrame
+
     def __init__(
         self,
         data=None,
@@ -369,12 +368,14 @@ class DataFrame(BasePandasDataset):
         elif hashable(by) and not isinstance(by, pandas.Grouper):
             drop = by in self.columns
             idx_name = by
-            if self._query_compiler.has_multiindex(
-                axis=axis
-            ) and by in self._query_compiler.get_index_names(axis):
+            if (
+                self._query_compiler.has_multiindex(axis=axis)
+                and by in self._query_compiler.get_index_names(axis)
+                and by is not None
+            ):
                 # In this case we pass the string value of the name through to the
                 # partitions. This is more efficient than broadcasting the values.
-                pass
+                level, by = by, None
             elif level is None:
                 by = self.__getitem__(by)._query_compiler
         elif isinstance(by, Series):
@@ -1368,6 +1369,7 @@ class DataFrame(BasePandasDataset):
         if min_count > 1:
             return data._reduce_dimension(
                 data._query_compiler.prod_min_count(
+                    squeeze_self=False,
                     axis=axis,
                     skipna=skipna,
                     level=level,
@@ -1378,6 +1380,7 @@ class DataFrame(BasePandasDataset):
             )
         return data._reduce_dimension(
             data._query_compiler.prod(
+                squeeze_self=False,
                 axis=axis,
                 skipna=skipna,
                 level=level,
@@ -1711,6 +1714,7 @@ class DataFrame(BasePandasDataset):
         if min_count > 1:
             return data._reduce_dimension(
                 data._query_compiler.sum_min_count(
+                    squeeze_self=False,
                     axis=axis,
                     skipna=skipna,
                     level=level,
@@ -1721,6 +1725,7 @@ class DataFrame(BasePandasDataset):
             )
         return data._reduce_dimension(
             data._query_compiler.sum(
+                squeeze_self=False,
                 axis=axis,
                 skipna=skipna,
                 level=level,
@@ -2094,9 +2099,6 @@ class DataFrame(BasePandasDataset):
     def __round__(self, decimals=0):
         return self._default_to_pandas(pandas.DataFrame.__round__, decimals=decimals)
 
-    def __setstate__(self, state):
-        return self._default_to_pandas(pandas.DataFrame.__setstate__, state)
-
     def __delitem__(self, key):
         if key not in self:
             raise KeyError(key)
@@ -2132,14 +2134,6 @@ class DataFrame(BasePandasDataset):
 
         self._default_to_pandas(attrs)
 
-    @property
-    def __doc__(self):  # pragma: no cover
-        def __doc__(df):
-            """Define __name__ attr because properties do not have it."""
-            return df.__doc__
-
-        return self._default_to_pandas(__doc__)
-
     @property
     def style(self):
         def style(df):
@@ -2416,6 +2410,29 @@ class DataFrame(BasePandasDataset):
         else:
             return self._getitem_column(key)
 
+    # Persistance support methods - BEGIN
+    @classmethod
+    def _inflate_light(cls, query_compiler):
+        """
+        Re-creates the object from previously-serialized lightweight representation.
+
+        The method is used for faster but not disk-storable persistence.
+        """
+        return cls(query_compiler=query_compiler)
+
+    @classmethod
+    def _inflate_full(cls, pandas_df):
+        """Re-creates the object from previously-serialized disk-storable representation."""
+        return cls(data=from_pandas(pandas_df))
+
+    def __reduce__(self):
+        self._query_compiler.finalize()
+        if PersistentPickle.get():
+            return self._inflate_full, (self._to_pandas(),)
+        return self._inflate_light, (self._query_compiler,)
+
+    # Persistance support methods - END
+
 
 if IsExperimental.get():
     from modin.experimental.cloud.meta_magic import make_wrapped_class
