@@ -914,6 +914,7 @@ def test_series_groupby(by, as_index_series_or_dataframe):
         eval_max(modin_groupby, pandas_groupby)
         eval_len(modin_groupby, pandas_groupby)
         eval_sum(modin_groupby, pandas_groupby)
+        eval_size(modin_groupby, pandas_groupby)
         eval_ngroup(modin_groupby, pandas_groupby)
         eval_nunique(modin_groupby, pandas_groupby)
         eval_median(modin_groupby, pandas_groupby)
@@ -1169,25 +1170,45 @@ def test_groupby_on_index_values_with_loop():
         df_equals(modin_dict[k], pandas_dict[k])
 
 
-def test_groupby_multiindex():
+@pytest.mark.parametrize(
+    "groupby_kwargs",
+    [
+        pytest.param({"level": 1, "axis": 1}, id="level_idx_axis=1"),
+        pytest.param({"level": 1}, id="level_idx"),
+        pytest.param({"level": [1, "four"]}, id="level_idx+name"),
+        pytest.param({"by": "four"}, id="level_name"),
+        pytest.param({"by": ["one", "two"]}, id="level_name_multi_by"),
+        pytest.param({"by": ["item0", "one", "two"]}, id="col_name+level_name"),
+    ],
+)
+def test_groupby_multiindex(groupby_kwargs):
     frame_data = np.random.randint(0, 100, size=(2 ** 6, 2 ** 4))
     modin_df = pd.DataFrame(frame_data)
     pandas_df = pandas.DataFrame(frame_data)
 
+    new_index = pandas.Index([f"item{i}" for i in range(len(pandas_df))])
     new_columns = pandas.MultiIndex.from_tuples(
         [(i // 4, i // 2, i) for i in modin_df.columns], names=["four", "two", "one"]
     )
     modin_df.columns = new_columns
+    modin_df.index = new_index
     pandas_df.columns = new_columns
-    modin_df.groupby(level=1, axis=1).sum()
+    pandas_df.index = new_index
 
-    modin_df = modin_df.T
-    pandas_df = pandas_df.T
-    df_equals(modin_df.groupby(level=1).count(), pandas_df.groupby(level=1).count())
-    df_equals(modin_df.groupby(by="four").count(), pandas_df.groupby(by="four").count())
+    if groupby_kwargs.get("axis", 0) == 0:
+        modin_df = modin_df.T
+        pandas_df = pandas_df.T
 
-    by = ["one", "two"]
-    df_equals(modin_df.groupby(by=by).count(), pandas_df.groupby(by=by).count())
+    md_grp, pd_grp = modin_df.groupby(**groupby_kwargs), pandas_df.groupby(
+        **groupby_kwargs
+    )
+    modin_groupby_equals_pandas(md_grp, pd_grp)
+    df_equals(md_grp.sum(), pd_grp.sum())
+    df_equals(md_grp.size(), pd_grp.size())
+    # Grouping on level works incorrect in case of aggregation:
+    # https://github.com/modin-project/modin/issues/2912
+    # df_equals(md_grp.quantile(), pd_grp.quantile())
+    df_equals(md_grp.first(), pd_grp.first())
 
 
 @pytest.mark.parametrize("groupby_axis", [0, 1])
