@@ -277,8 +277,8 @@ class TestCsv:
         skip_blank_lines,
     ):
         if request.config.getoption("--simulate-cloud").lower() != "off":
-            pytest.skip(
-                "The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
+            pytest.xfail(
+                reason="The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
             )
         eval_io(
             fn_name="read_csv",
@@ -323,8 +323,8 @@ class TestCsv:
         skipfooter,
     ):
         if request.config.getoption("--simulate-cloud").lower() != "off":
-            pytest.skip(
-                "The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
+            pytest.xfail(
+                reason="The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
             )
 
         if dtype:
@@ -353,16 +353,7 @@ class TestCsv:
     @pytest.mark.parametrize("skiprows", [2, lambda x: x % 2])
     @pytest.mark.parametrize("skipfooter", [0, 10])
     @pytest.mark.parametrize("nrows", [35, None])
-    @pytest.mark.parametrize(
-        "names",
-        [
-            pytest.param(
-                ["c1", "c2", "c3", "c4"],
-                marks=pytest.mark.xfail(reason="Excluded because of the issue #2845"),
-            ),
-            None,
-        ],
-    )
+    @pytest.mark.parametrize("names", [["c1", "c2", "c3", "c4"], None])
     def test_read_csv_parsing_2(
         self,
         request,
@@ -376,8 +367,8 @@ class TestCsv:
         if false_values or true_values and Engine.get() != "Python":
             pytest.xfail("modin and pandas dataframes differs - issue #2446")
         if request.config.getoption("--simulate-cloud").lower() != "off":
-            pytest.skip(
-                "The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
+            pytest.xfail(
+                reason="The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
             )
 
         eval_io(
@@ -406,11 +397,29 @@ class TestCsv:
 
         eval_io_from_str(str_initial_spaces, unique_filename, skipinitialspace=True)
 
-    @pytest.mark.xfail(reason="infinite recursion error - issue #2032")
     @pytest.mark.parametrize(
-        "test_case", ["single_element", "single_column", "multiple_columns"]
+        "test_case",
+        [
+            pytest.param(
+                "single_element",
+                marks=pytest.mark.xfail(
+                    reason="infinite recursion error - issue #2032"
+                ),
+            ),
+            pytest.param(
+                "single_column",
+                marks=pytest.mark.xfail(
+                    reason="infinite recursion error - issue #2032"
+                ),
+            ),
+            "multiple_columns",
+        ],
     )
-    def test_read_csv_squeeze(self, test_case):
+    def test_read_csv_squeeze(self, request, test_case):
+        if request.config.getoption("--simulate-cloud").lower() != "off":
+            pytest.xfail(
+                reason="The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
+            )
         unique_filename = get_unique_filename()
 
         str_single_element = "1"
@@ -459,21 +468,7 @@ class TestCsv:
 
     # Datetime Handling tests
     @pytest.mark.parametrize(
-        "parse_dates",
-        [
-            True,
-            False,
-            ["col2"],
-            ["col2", "col4"],
-            [1, 3],
-            pytest.param(
-                {"foo": ["col2", "col4"]},
-                marks=pytest.mark.xfail(
-                    Engine.get() != "Python",
-                    reason="Exception: Internal Error - issue #2073",
-                ),
-            ),
-        ],
+        "parse_dates", [True, False, ["col2"], ["col2", "col4"], [1, 3]]
     )
     @pytest.mark.parametrize("infer_datetime_format", [True, False])
     @pytest.mark.parametrize("keep_date_col", [True, False])
@@ -493,8 +488,8 @@ class TestCsv:
         cache_dates,
     ):
         if request.config.getoption("--simulate-cloud").lower() != "off":
-            pytest.skip(
-                "The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
+            pytest.xfail(
+                reason="The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
             )
 
         raising_exceptions = io_ops_bad_exc  # default value
@@ -609,8 +604,8 @@ class TestCsv:
         dialect,
     ):
         if request.config.getoption("--simulate-cloud").lower() != "off":
-            pytest.skip(
-                "The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
+            pytest.xfail(
+                reason="The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
             )
         elif Engine.get() != "Python" and lineterminator == "x":
             pytest.xfail("read_csv with Ray engine outputs empty frame - issue #2493")
@@ -809,8 +804,8 @@ class TestCsv:
 
     def test_read_csv_categories(self, request):
         if request.config.getoption("--simulate-cloud").lower() != "off":
-            pytest.skip(
-                "The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
+            pytest.xfail(
+                reason="The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
             )
         eval_io(
             fn_name="read_csv",
@@ -838,8 +833,8 @@ class TestCsv:
             parse_dates
             and request.config.getoption("--simulate-cloud").lower() != "off"
         ):
-            pytest.skip(
-                "The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
+            pytest.xfail(
+                reason="The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
             )
 
         if names is not None and header == "infer":
@@ -858,7 +853,6 @@ class TestCsv:
             encoding=encoding,
         )
 
-    @pytest.mark.skipif(Engine.get() == "Python", reason="Using pandas implementation")
     def test_read_csv_s3(self):
         eval_io(
             fn_name="read_csv",
@@ -880,8 +874,8 @@ class TestCsv:
 
     def test_read_csv_default_to_pandas(self, request):
         if request.config.getoption("--simulate-cloud").lower() != "off":
-            pytest.skip(
-                "The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
+            pytest.xfail(
+                reason="The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
             )
         with pytest.warns(UserWarning):
             # This tests that we default to pandas on a buffer
@@ -899,8 +893,8 @@ class TestCsv:
 
     def test_read_csv_default_to_pandas_url(self, request):
         if request.config.getoption("--simulate-cloud").lower() != "off":
-            pytest.skip(
-                "The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
+            pytest.xfail(
+                reason="The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
             )
         # We haven't implemented read_csv from https, but if it's implemented, then this needs to change
         eval_io(
@@ -924,8 +918,8 @@ class TestCsv:
 
     def test_read_csv_sep_none(self, request):
         if request.config.getoption("--simulate-cloud").lower() != "off":
-            pytest.skip(
-                "The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
+            pytest.xfail(
+                reason="The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
             )
         eval_io(
             fn_name="read_csv",
@@ -937,8 +931,8 @@ class TestCsv:
 
     def test_read_csv_incorrect_data(self, request):
         if request.config.getoption("--simulate-cloud").lower() != "off":
-            pytest.skip(
-                "The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
+            pytest.xfail(
+                reason="The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
             )
         eval_io(
             fn_name="read_csv",
@@ -957,8 +951,8 @@ class TestCsv:
     )
     def test_read_csv_names_neq_num_cols(self, request, kwargs):
         if request.config.getoption("--simulate-cloud").lower() != "off":
-            pytest.skip(
-                "The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
+            pytest.xfail(
+                reason="The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
             )
         eval_io(
             fn_name="read_csv",
@@ -971,8 +965,8 @@ class TestCsv:
     @pytest.mark.parametrize("mode", ["w", "wb+"])
     def test_to_csv(self, request, header, mode):
         if request.config.getoption("--simulate-cloud").lower() != "off":
-            pytest.skip(
-                "The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
+            pytest.xfail(
+                reason="The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
             )
 
         pandas_df = generate_dataframe()
@@ -989,8 +983,8 @@ class TestCsv:
 
     def test_dataframe_to_csv(self, request):
         if request.config.getoption("--simulate-cloud").lower() != "off":
-            pytest.skip(
-                "The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
+            pytest.xfail(
+                reason="The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
             )
         pandas_df = pandas.read_csv(pytest.csvs_names["test_read_csv_regular"])
         modin_df = pd.DataFrame(pandas_df)
@@ -1000,8 +994,8 @@ class TestCsv:
 
     def test_series_to_csv(self, request):
         if request.config.getoption("--simulate-cloud").lower() != "off":
-            pytest.skip(
-                "The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
+            pytest.xfail(
+                reason="The reason of tests fail in `cloud` mode is unknown for now - issue #2340"
             )
         pandas_s = pandas.read_csv(
             pytest.csvs_names["test_read_csv_regular"], usecols=["col1"]
@@ -1032,7 +1026,7 @@ class TestCsv:
     @pytest.mark.parametrize("read_mode", ["r", "rb"])
     def test_read_csv_file_handle(self, request, read_mode, make_csv_file):
         if request.config.getoption("--simulate-cloud").lower() != "off":
-            pytest.skip("Cannot pickle file handles. See comments in PR #2625")
+            pytest.xfail("Cannot pickle file handles. See comments in PR #2625")
 
         unique_filename = get_unique_filename()
         make_csv_file(filename=unique_filename)
@@ -1164,7 +1158,7 @@ class TestParquet:
             path="modin/pandas/test/data/hdfs.parquet",
         )
 
-    @pytest.mark.skipif(
+    @pytest.mark.xfail(
         Engine.get() == "Python",
         reason="S3-like path doesn't support in pandas with anonymous credentials. See issue #2301.",
     )
@@ -1274,7 +1268,7 @@ class TestJson:
     @pytest.mark.parametrize("read_mode", ["r", "rb"])
     def test_read_json_file_handle(self, request, read_mode):
         if request.config.getoption("--simulate-cloud").lower() != "off":
-            pytest.skip("Cannot pickle file handles. See comments in PR #2625")
+            pytest.xfail("Cannot pickle file handles. See comments in PR #2625")
         unique_filename = get_unique_filename(extension="json")
         try:
             setup_json_file(filename=unique_filename)
@@ -1352,7 +1346,8 @@ class TestExcel:
             teardown_test_files([unique_filename])
 
     @pytest.mark.xfail(
-        reason="pandas throws the exception. See pandas issue #39250 for more info"
+        Engine.get() != "Python",
+        reason="pandas throws the exception. See pandas issue #39250 for more info",
     )
     @check_file_leaks
     def test_read_excel_sheetname_title(self):
@@ -1429,7 +1424,6 @@ class TestExcel:
 
 
 class TestHdf:
-    @pytest.mark.skipif(os.name == "nt", reason="Windows not supported")
     @pytest.mark.parametrize("format", [None, "table"])
     def test_read_hdf(self, format):
         unique_filename = get_unique_filename(extension="hdf")
@@ -1444,7 +1438,6 @@ class TestHdf:
         finally:
             teardown_test_files([unique_filename])
 
-    @pytest.mark.skipif(os.name == "nt", reason="Windows not supported")
     def test_HDFStore(self):
         try:
             unique_filename_modin = get_unique_filename(extension="hdf")
@@ -1790,7 +1783,7 @@ class TestFwf:
     @pytest.mark.parametrize("read_mode", ["r", "rb"])
     def test_read_fwf_file_handle(self, request, read_mode):
         if request.config.getoption("--simulate-cloud").lower() != "off":
-            pytest.skip("Cannot pickle file handles. See comments in PR #2625")
+            pytest.xfail("Cannot pickle file handles. See comments in PR #2625")
         unique_filename = get_unique_filename(extension="txt")
         try:
             setup_fwf_file(filename=unique_filename)
@@ -1805,7 +1798,7 @@ class TestFwf:
 
 
 class TestGbq:
-    @pytest.mark.skip(reason="Need to verify GBQ access")
+    @pytest.mark.xfail(reason="Need to verify GBQ access")
     def test_read_gbq(self):
         # Test API, but do not supply credentials until credits can be secured.
         with pytest.raises(
@@ -1813,7 +1806,7 @@ class TestGbq:
         ):
             pd.read_gbq("SELECT 1")
 
-    @pytest.mark.skip(reason="Need to verify GBQ access")
+    @pytest.mark.xfail(reason="Need to verify GBQ access")
     def test_to_gbq(self):
         modin_df, _ = create_test_dfs(TEST_DATA)
         # Test API, but do not supply credentials until credits can be secured.
@@ -1844,10 +1837,6 @@ class TestStata:
 
 
 class TestFeather:
-    @pytest.mark.xfail(
-        Engine.get() != "Python",
-        reason="Excluded because of the issue #2845",
-    )
     def test_read_feather(self):
         unique_filename = get_unique_filename(extension="feather")
         try:
@@ -1872,13 +1861,13 @@ class TestFeather:
 
 
 class TestClipboard:
-    @pytest.mark.skip(reason="No clipboard on Travis")
+    @pytest.mark.skip(reason="No clipboard in CI")
     def test_read_clipboard(self):
         setup_clipboard()
 
         eval_io(fn_name="read_clipboard")
 
-    @pytest.mark.skip(reason="No clipboard on Travis")
+    @pytest.mark.skip(reason="No clipboard in CI")
     def test_to_clipboard(self):
         modin_df, pandas_df = create_test_dfs(TEST_DATA)
 
